package androidx.camera.core;

import android.view.Surface;
import androidx.annotation.GuardedBy;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.camera.core.ForwardingImageProxy;
import androidx.camera.core.impl.ImageReaderProxy;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.concurrent.Executor;

public final class QueuedImageReaderProxy implements ImageReaderProxy, ForwardingImageProxy.OnImageCloseListener {
    @GuardedBy("this")
    private final Set<ImageProxy> mAcquiredImages = new HashSet();
    @GuardedBy("this")
    private boolean mClosed;
    @GuardedBy("this")
    private int mCurrentPosition;
    private final int mFormat;
    private final int mHeight;
    @GuardedBy("this")
    private final List<ImageProxy> mImages;
    private final int mMaxImages;
    @Nullable
    @GuardedBy("this")
    private Executor mOnImageAvailableExecutor;
    @Nullable
    @GuardedBy("this")
    private ImageReaderProxy.OnImageAvailableListener mOnImageAvailableListener;
    @GuardedBy("this")
    private final Set<OnReaderCloseListener> mOnReaderCloseListeners = new HashSet();
    @GuardedBy("this")
    private final Surface mSurface;
    private final int mWidth;

    public interface OnReaderCloseListener {
        void onReaderClose(ImageReaderProxy imageReaderProxy);
    }

    public QueuedImageReaderProxy(int i2, int i3, int i4, int i5, Surface surface) {
        this.mWidth = i2;
        this.mHeight = i3;
        this.mFormat = i4;
        this.mMaxImages = i5;
        this.mSurface = surface;
        this.mImages = new ArrayList(i5);
        this.mCurrentPosition = 0;
        this.mClosed = false;
    }

    private synchronized void notifyOnReaderCloseListeners() {
        for (OnReaderCloseListener onReaderCloseListener : this.mOnReaderCloseListeners) {
            onReaderCloseListener.onReaderClose(this);
        }
    }

    private synchronized void throwExceptionIfClosed() {
        if (this.mClosed) {
            throw new IllegalStateException("This reader is already closed.");
        }
    }

    @Override // androidx.camera.core.impl.ImageReaderProxy
    @Nullable
    public synchronized ImageProxy acquireLatestImage() {
        throwExceptionIfClosed();
        if (this.mImages.isEmpty()) {
            return null;
        }
        if (this.mCurrentPosition < this.mImages.size()) {
            ArrayList arrayList = new ArrayList();
            for (int i2 = 0; i2 < this.mImages.size() - 1; i2++) {
                if (!this.mAcquiredImages.contains(this.mImages.get(i2))) {
                    arrayList.add(this.mImages.get(i2));
                }
            }
            Iterator it = arrayList.iterator();
            while (it.hasNext()) {
                ((ImageProxy) it.next()).close();
            }
            int size = this.mImages.size() - 1;
            this.mCurrentPosition = size;
            List<ImageProxy> list = this.mImages;
            this.mCurrentPosition = size + 1;
            ImageProxy imageProxy = list.get(size);
            this.mAcquiredImages.add(imageProxy);
            return imageProxy;
        }
        throw new IllegalStateException("Max images have already been acquired without close.");
    }

    @Override // androidx.camera.core.impl.ImageReaderProxy
    @Nullable
    public synchronized ImageProxy acquireNextImage() {
        throwExceptionIfClosed();
        if (this.mImages.isEmpty()) {
            return null;
        }
        if (this.mCurrentPosition < this.mImages.size()) {
            List<ImageProxy> list = this.mImages;
            int i2 = this.mCurrentPosition;
            this.mCurrentPosition = i2 + 1;
            ImageProxy imageProxy = list.get(i2);
            this.mAcquiredImages.add(imageProxy);
            return imageProxy;
        }
        throw new IllegalStateException("Max images have already been acquired without close.");
    }

    public synchronized void addOnReaderCloseListener(OnReaderCloseListener onReaderCloseListener) {
        this.mOnReaderCloseListeners.add(onReaderCloseListener);
    }

    @Override // androidx.camera.core.impl.ImageReaderProxy
    public synchronized void close() {
        if (!this.mClosed) {
            this.mOnImageAvailableExecutor = null;
            this.mOnImageAvailableListener = null;
            Iterator it = new ArrayList(this.mImages).iterator();
            while (it.hasNext()) {
                ((ImageProxy) it.next()).close();
            }
            this.mImages.clear();
            this.mClosed = true;
            notifyOnReaderCloseListeners();
        }
    }

    public synchronized void enqueueImage(ForwardingImageProxy forwardingImageProxy) {
        Executor executor;
        throwExceptionIfClosed();
        if (this.mImages.size() < this.mMaxImages) {
            this.mImages.add(forwardingImageProxy);
            forwardingImageProxy.addOnImageCloseListener(this);
            final ImageReaderProxy.OnImageAvailableListener onImageAvailableListener = this.mOnImageAvailableListener;
            if (!(onImageAvailableListener == null || (executor = this.mOnImageAvailableExecutor) == null)) {
                executor.execute(new Runnable() {
                    /* class androidx.camera.core.QueuedImageReaderProxy.AnonymousClass1 */

                    public void run() {
                        if (!QueuedImageReaderProxy.this.isClosed()) {
                            onImageAvailableListener.onImageAvailable(QueuedImageReaderProxy.this);
                        }
                    }
                });
            }
        } else {
            forwardingImageProxy.close();
        }
    }

    public synchronized int getCurrentImages() {
        throwExceptionIfClosed();
        return this.mImages.size();
    }

    @Override // androidx.camera.core.impl.ImageReaderProxy
    public int getHeight() {
        throwExceptionIfClosed();
        return this.mHeight;
    }

    @Override // androidx.camera.core.impl.ImageReaderProxy
    public int getImageFormat() {
        throwExceptionIfClosed();
        return this.mFormat;
    }

    @Override // androidx.camera.core.impl.ImageReaderProxy
    public int getMaxImages() {
        throwExceptionIfClosed();
        return this.mMaxImages;
    }

    @Override // androidx.camera.core.impl.ImageReaderProxy
    @NonNull
    public synchronized Surface getSurface() {
        throwExceptionIfClosed();
        return this.mSurface;
    }

    @Override // androidx.camera.core.impl.ImageReaderProxy
    public int getWidth() {
        throwExceptionIfClosed();
        return this.mWidth;
    }

    public synchronized boolean isClosed() {
        return this.mClosed;
    }

    @Override // androidx.camera.core.ForwardingImageProxy.OnImageCloseListener
    public synchronized void onImageClose(ImageProxy imageProxy) {
        int indexOf = this.mImages.indexOf(imageProxy);
        if (indexOf >= 0) {
            this.mImages.remove(indexOf);
            int i2 = this.mCurrentPosition;
            if (indexOf <= i2) {
                this.mCurrentPosition = i2 - 1;
            }
        }
        this.mAcquiredImages.remove(imageProxy);
    }

    @Override // androidx.camera.core.impl.ImageReaderProxy
    public synchronized void setOnImageAvailableListener(@NonNull ImageReaderProxy.OnImageAvailableListener onImageAvailableListener, @NonNull Executor executor) {
        throwExceptionIfClosed();
        this.mOnImageAvailableListener = onImageAvailableListener;
        this.mOnImageAvailableExecutor = executor;
    }
}
