package androidx.camera.core.impl;

import android.util.Log;
import androidx.annotation.GuardedBy;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.WorkerThread;
import androidx.camera.core.Camera;
import androidx.camera.core.impl.CameraInternal;
import androidx.core.util.Preconditions;
import b.a.a.w0.i;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.Executor;
import java.util.concurrent.RejectedExecutionException;

public final class CameraStateRegistry {
    private static final boolean DEBUG = Log.isLoggable(TAG, 3);
    private static final String TAG = "CameraStateRegistry";
    @GuardedBy("mLock")
    private int mAvailableCameras;
    @GuardedBy("mLock")
    private final Map<Camera, CameraRegistration> mCameraStates;
    private StringBuilder mDebugString;
    private final Object mLock;
    private final int mMaxAllowedOpenedCameras;

    public static class CameraRegistration {
        private final OnOpenAvailableListener mCameraAvailableListener;
        private final Executor mNotifyExecutor;
        private CameraInternal.State mState;

        public CameraRegistration(@Nullable CameraInternal.State state, @NonNull Executor executor, @NonNull OnOpenAvailableListener onOpenAvailableListener) {
            this.mState = state;
            this.mNotifyExecutor = executor;
            this.mCameraAvailableListener = onOpenAvailableListener;
        }

        public CameraInternal.State getState() {
            return this.mState;
        }

        public void notifyListener() {
            try {
                Executor executor = this.mNotifyExecutor;
                OnOpenAvailableListener onOpenAvailableListener = this.mCameraAvailableListener;
                Objects.requireNonNull(onOpenAvailableListener);
                executor.execute(new i(onOpenAvailableListener));
            } catch (RejectedExecutionException e2) {
                Log.e(CameraStateRegistry.TAG, "Unable to notify camera.", e2);
            }
        }

        public CameraInternal.State setState(@Nullable CameraInternal.State state) {
            CameraInternal.State state2 = this.mState;
            this.mState = state;
            return state2;
        }
    }

    public interface OnOpenAvailableListener {
        void onOpenAvailable();
    }

    public CameraStateRegistry(int i2) {
        this.mDebugString = DEBUG ? new StringBuilder() : null;
        this.mLock = new Object();
        this.mCameraStates = new HashMap();
        this.mMaxAllowedOpenedCameras = i2;
        synchronized ("mLock") {
            this.mAvailableCameras = i2;
        }
    }

    private static boolean isOpen(@Nullable CameraInternal.State state) {
        return state != null && state.holdsCameraSlot();
    }

    @GuardedBy("mLock")
    @WorkerThread
    private void recalculateAvailableCameras() {
        if (DEBUG) {
            this.mDebugString.setLength(0);
            this.mDebugString.append("Recalculating open cameras:\n");
            this.mDebugString.append(String.format(Locale.US, "%-45s%-22s\n", "Camera", "State"));
            this.mDebugString.append("-------------------------------------------------------------------\n");
        }
        int i2 = 0;
        for (Map.Entry<Camera, CameraRegistration> entry : this.mCameraStates.entrySet()) {
            if (DEBUG) {
                this.mDebugString.append(String.format(Locale.US, "%-45s%-22s\n", entry.getKey().toString(), entry.getValue().getState() != null ? entry.getValue().getState().toString() : "UNKNOWN"));
            }
            if (isOpen(entry.getValue().getState())) {
                i2++;
            }
        }
        if (DEBUG) {
            this.mDebugString.append("-------------------------------------------------------------------\n");
            this.mDebugString.append(String.format(Locale.US, "Open count: %d (Max allowed: %d)", Integer.valueOf(i2), Integer.valueOf(this.mMaxAllowedOpenedCameras)));
            Log.d(TAG, this.mDebugString.toString());
        }
        this.mAvailableCameras = Math.max(this.mMaxAllowedOpenedCameras - i2, 0);
    }

    @Nullable
    @GuardedBy("mLock")
    private CameraInternal.State unregisterCamera(Camera camera) {
        CameraRegistration remove = this.mCameraStates.remove(camera);
        if (remove == null) {
            return null;
        }
        recalculateAvailableCameras();
        return remove.getState();
    }

    @Nullable
    @GuardedBy("mLock")
    private CameraInternal.State updateAndVerifyState(@NonNull Camera camera, @NonNull CameraInternal.State state) {
        CameraInternal.State state2 = ((CameraRegistration) Preconditions.checkNotNull(this.mCameraStates.get(camera), "Cannot update state of camera which has not yet been registered. Register with CameraAvailabilityRegistry.registerCamera()")).setState(state);
        CameraInternal.State state3 = CameraInternal.State.OPENING;
        if (state == state3) {
            Preconditions.checkState(isOpen(state) || state2 == state3, "Cannot mark camera as opening until camera was successful at calling CameraAvailabilityRegistry.tryOpen()");
        }
        if (state2 != state) {
            recalculateAvailableCameras();
        }
        return state2;
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:36:0x0066 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r5v2, types: [java.util.List] */
    /* JADX WARN: Type inference failed for: r5v4 */
    /* JADX WARN: Type inference failed for: r5v7, types: [java.util.List] */
    /* JADX WARN: Type inference failed for: r5v8, types: [java.util.ArrayList] */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x0067, code lost:
        if (r5 == 0) goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x0069, code lost:
        r5 = r5.iterator();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:30:0x0071, code lost:
        if (r5.hasNext() == false) goto L_0x007d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:31:0x0073, code lost:
        ((androidx.camera.core.impl.CameraStateRegistry.CameraRegistration) r5.next()).notifyListener();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:40:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:41:?, code lost:
        return;
     */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void markCameraState(@NonNull Camera camera, @NonNull CameraInternal.State state) {
        CameraInternal.State state2;
        ?? r5;
        synchronized (this.mLock) {
            int i2 = this.mAvailableCameras;
            if (state == CameraInternal.State.RELEASED) {
                state2 = unregisterCamera(camera);
            } else {
                state2 = updateAndVerifyState(camera, state);
            }
            if (state2 != state) {
                if (i2 >= 1 || this.mAvailableCameras <= 0) {
                    r5 = (state != CameraInternal.State.PENDING_OPEN || this.mAvailableCameras <= 0) ? 0 : Collections.singletonList(this.mCameraStates.get(camera));
                } else {
                    r5 = new ArrayList();
                    for (Map.Entry<Camera, CameraRegistration> entry : this.mCameraStates.entrySet()) {
                        if (entry.getValue().getState() == CameraInternal.State.PENDING_OPEN) {
                            r5.add(entry.getValue());
                        }
                    }
                }
            }
        }
    }

    public void registerCamera(@NonNull Camera camera, @NonNull Executor executor, @NonNull OnOpenAvailableListener onOpenAvailableListener) {
        synchronized (this.mLock) {
            boolean z = !this.mCameraStates.containsKey(camera);
            Preconditions.checkState(z, "Camera is already registered: " + camera);
            this.mCameraStates.put(camera, new CameraRegistration(null, executor, onOpenAvailableListener));
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x0067  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x008c  */
    public boolean tryOpenCamera(@NonNull Camera camera) {
        boolean z;
        synchronized (this.mLock) {
            CameraRegistration cameraRegistration = (CameraRegistration) Preconditions.checkNotNull(this.mCameraStates.get(camera), "Camera must first be registered with registerCamera()");
            boolean z2 = DEBUG;
            if (z2) {
                this.mDebugString.setLength(0);
                this.mDebugString.append(String.format(Locale.US, "tryOpenCamera(%s) [Available Cameras: %d, Already Open: %b (Previous state: %s)]", camera, Integer.valueOf(this.mAvailableCameras), Boolean.valueOf(isOpen(cameraRegistration.getState())), cameraRegistration.getState()));
            }
            if (this.mAvailableCameras <= 0) {
                if (!isOpen(cameraRegistration.getState())) {
                    z = false;
                    if (z2) {
                        StringBuilder sb = this.mDebugString;
                        Locale locale = Locale.US;
                        Object[] objArr = new Object[1];
                        objArr[0] = z ? "SUCCESS" : "FAIL";
                        sb.append(String.format(locale, " --> %s", objArr));
                        Log.d(TAG, this.mDebugString.toString());
                    }
                    if (z) {
                        recalculateAvailableCameras();
                    }
                }
            }
            cameraRegistration.setState(CameraInternal.State.OPENING);
            z = true;
            if (z2) {
            }
            if (z) {
            }
        }
        return z;
    }
}
